@@ -29,7 +29,7 @@ static int char_comp(const void * lhs, const void * rhs) {
 }
 
 
-int main() {
+int main(void) {
 	febug_start();
 	febug_register_type(CSTRING_FEBUG_TP, cstring_febug_formatter);
 
